@@ -109,14 +109,16 @@ sbf <- function (x, ...) UseMethod("sbf")
   numFeat <- ncol(x)
   classLevels <- levels(y)
 
-  if(is.null(sbfControl$index))
-    sbfControl$index <- switch(tolower(sbfControl$method),
-                               cv = createFolds(y, sbfControl$number, returnTrain = TRUE),
-                               loocv = createFolds(y, length(y), returnTrain = TRUE),
-                               boot = createResample(y, sbfControl$number),
-                               test = createDataPartition(y, 1, sbfControl$p),
-                               lgocv = createDataPartition(y, sbfControl$number, sbfControl$p))
-  names(sbfControl$index) <- prettySeq(sbfControl$index)
+  if(is.null(sbfControl$index)) sbfControl$index <- switch(
+                                                           tolower(sbfControl$method),
+                                                           cv = createFolds(y, sbfControl$number, returnTrain = TRUE),
+                                                           repeatedcv = createMultiFolds(y, sbfControl$number, sbfControl$repeats),
+                                                           loocv = createFolds(y, length(y), returnTrain = TRUE),
+                                                           boot =, boot632 = createResample(y, sbfControl$number),
+                                                           test = createDataPartition(y, 1, sbfControl$p),
+                                                           lgocv = createDataPartition(y, sbfControl$number, sbfControl$p))
+
+  if(is.null(names(sbfControl$index))) names(sbfControl$index) <- prettySeq(sbfControl$index)
   
   ## check summary function and metric
   testOutput <- data.frame(pred = sample(y, min(10, length(y))),
@@ -163,13 +165,21 @@ sbf <- function (x, ...) UseMethod("sbf")
   resamples <- lapply(sbfPred,
                       sbfControl$functions$summary,
                       lev = classLevels)
-  resamples <- as.data.frame(do.call("rbind", resamples))
+  pNames <- names(resamples[[1]])
+  rNames <- names(resamples)
+  ##On 9/10/10 10:24 AM, "Hadley Wickham" <hadley@rice.edu> wrote:
+  resamples <-matrix(unlist(resamples),
+                     nrow = length(resamples),
+                     dimnames = list(NULL, NULL),
+                     byrow = TRUE)
+  colnames(resamples) <- pNames  
+  resamples <- as.data.frame(resamples)
 
   externPerf <- cbind(t(apply(resamples, 2, mean, na.rm = TRUE)),
                       t(apply(resamples, 2, sd, na.rm = TRUE)))
   colnames(externPerf)<- c(perfNames, paste(perfNames, "SD", sep = ""))
 
-  resamples$Resample <- rownames(resamples)
+  resamples$Resample <- rNames
   
   #########################################################################
 
@@ -344,7 +354,8 @@ predict.sbf <- function(object, newdata = NULL, ...)
 sbfControl <- function(functions = NULL,
                        method = "boot",
                        saveDetails = FALSE,
-                       number = ifelse(method == "cv", 10, 25),
+                       number = ifelse(method %in% c("cv", "repeatedcv"), 10, 25),
+                       repeats = ifelse(method %in% c("cv", "repeatedcv"), 1, number),
                        verbose = TRUE,
                        returnResamp = "all",
                        p = .75,
@@ -358,6 +369,7 @@ sbfControl <- function(functions = NULL,
        method = method,
        saveDetails = saveDetails,
        number = number,
+       repeats = repeats,
        returnResamp = returnResamp,
        verbose = verbose,
        p = p,
